==> vim-gruvbox_2.0.0.orig.tar.gz: gruvbox-2.0.0/gruvbox_256palette.sh <==
#!/bin/sh

if [ "${TERM%%-*}" = "screen" ]; then
  if [ -n "$TMUX" ]; then
    printf "\033Ptmux;\033\033]4;236;rgb:32/30/2f\007\033\\"
    printf "\033Ptmux;\033\033]4;234;rgb:1d/20/21\007\033\\"

    printf "\033Ptmux;\033\033]4;235;rgb:28/28/28\007\033\\"
    printf "\033Ptmux;\033\033]4;237;rgb:3c/38/36\007\033\\"
    printf "\033Ptmux;\033\033]4;239;rgb:50/49/45\007\033\\"
    printf "\033Ptmux;\033\033]4;241;rgb:66/5c/54\007\033\\"
    printf "\033Ptmux;\033\033]4;243;rgb:7c/6f/64\007\033\\"

    printf "\033Ptmux;\033\033]4;244;rgb:92/83/74\007\033\\"
    printf "\033Ptmux;\033\033]4;245;rgb:92/83/74\007\033\\"

    printf "\033Ptmux;\033\033]4;228;rgb:f2/e5/bc\007\033\\"
    printf "\033Ptmux;\033\033]4;230;rgb:f9/f5/d7\007\033\\"

    printf "\033Ptmux;\033\033]4;229;rgb:fb/f1/c7\007\033\\"
    printf "\033Ptmux;\033\033]4;223;rgb:eb/db/b2\007\033\\"
    printf "\033Ptmux;\033\033]4;250;rgb:d5/c4/a1\007\033\\"
    printf "\033Ptmux;\033\033]4;248;rgb:bd/ae/93\007\033\\"
    printf "\033Ptmux;\033\033]4;246;rgb:a8/99/84\007\033\\"

    printf "\033Ptmux;\033\033]4;167;rgb:fb/49/34\007\033\\"
    printf "\033Ptmux;\033\033]4;142;rgb:b8/bb/26\007\033\\"
    printf "\033Ptmux;\033\033]4;214;rgb:fa/bd/2f\007\033\\"
    printf "\033Ptmux;\033\033]4;109;rgb:83/a5/98\007\033\\"
    printf "\033Ptmux;\033\033]4;175;rgb:d3/86/9b\007\033\\"
    printf "\033Ptmux;\033\033]4;108;rgb:8e/c0/7c\007\033\\"
    printf "\033Ptmux;\033\033]4;208;rgb:fe/80/19\007\033\\"

    printf "\033Ptmux;\033\033]4;88;rgb:9d/00/06\007\033\\"
    printf "\033Ptmux;\033\033]4;100;rgb:79/74/0e\007\033\\"
    printf "\033Ptmux;\033\033]4;136;rgb:b5/76/14\007\033\\"
    printf "\033Ptmux;\033\033]4;24;rgb:07/66/78\007\033\\"
    printf "\033Ptmux;\033\033]4;96;rgb:8f/3f/71\007\033\\"
    printf "\033Ptmux;\033\033]4;66;rgb:42/7b/58\007\033\\"
    printf "\033Ptmux;\033\033]4;130;rgb:af/3a/03\007\033\\"
  else
    printf "\033P\033]4;236;rgb:32/30/2f\007\033\\"
    printf "\033P\033]4;234;rgb:1d/20/21\007\033\\"

    printf "\033P\033]4;235;rgb:28/28/28\007\033\\"
    printf "\033P\033]4;237;rgb:3c/38/36\007\033\\"
    printf "\033P\033]4;239;rgb:50/49/45\007\033\\"
    printf "\033P\033]4;241;rgb:66/5c/54\007\033\\"
    printf "\033P\033]4;243;rgb:7c/6f/64\007\033\\"

    printf "\033P\033]4;244;rgb:92/83/74\007\033\\"
    printf "\033P\033]4;245;rgb:92/83/74\007\033\\"

    printf "\033P\033]4;228;rgb:f2/e5/bc\007\033\\"
    printf "\033P\033]4;230;rgb:f9/f5/d7\007\033\\"

    printf "\033P\033]4;229;rgb:fb/f1/c7\007\033\\"
    printf "\033P\033]4;223;rgb:eb/db/b2\007\033\\"
    printf "\033P\033]4;250;rgb:d5/c4/a1\007\033\\"
    printf "\033P\033]4;248;rgb:bd/ae/93\007\033\\"
    printf "\033P\033]4;246;rgb:a8/99/84\007\033\\"

    printf "\033P\033]4;167;rgb:fb/49/34\007\033\\"
    printf "\033P\033]4;142;rgb:b8/bb/26\007\033\\"
    printf "\033P\033]4;214;rgb:fa/bd/2f\007\033\\"
    printf "\033P\033]4;109;rgb:83/a5/98\007\033\\"
    printf "\033P\033]4;175;rgb:d3/86/9b\007\033\\"
    printf "\033P\033]4;108;rgb:8e/c0/7c\007\033\\"
    printf "\033P\033]4;208;rgb:fe/80/19\007\033\\"

    printf "\033P\033]4;88;rgb:9d/00/06\007\033\\"
    printf "\033P\033]4;100;rgb:79/74/0e\007\033\\"
    printf "\033P\033]4;136;rgb:b5/76/14\007\033\\"
    printf "\033P\033]4;24;rgb:07/66/78\007\033\\"
    printf "\033P\033]4;96;rgb:8f/3f/71\007\033\\"
    printf "\033P\033]4;66;rgb:42/7b/58\007\033\\"
    printf "\033P\033]4;130;rgb:af/3a/03\007\033\\"
  fi

elif [ "$TERM" != "linux" ] && [ "$TERM" != "vt100" ] && [ "$TERM" != "vt220" ]; then

  printf "\033]4;236;rgb:32/30/2f\033\\"
  printf "\033]4;234;rgb:1d/20/21\033\\"

  printf "\033]4;235;rgb:28/28/28\033\\"
  printf "\033]4;237;rgb:3c/38/36\033\\"
  printf "\033]4;239;rgb:50/49/45\033\\"
  printf "\033]4;241;rgb:66/5c/54\033\\"
  printf "\033]4;243;rgb:7c/6f/64\033\\"

  printf "\033]4;244;rgb:92/83/74\033\\"
  printf "\033]4;245;rgb:92/83/74\033\\"

  printf "\033]4;228;rgb:f2/e5/bc\033\\"
  printf "\033]4;230;rgb:f9/f5/d7\033\\"

  printf "\033]4;229;rgb:fb/f1/c7\033\\"
  printf "\033]4;223;rgb:eb/db/b2\033\\"
  printf "\033]4;250;rgb:d5/c4/a1\033\\"
  printf "\033]4;248;rgb:bd/ae/93\033\\"
  printf "\033]4;246;rgb:a8/99/84\033\\"

  printf "\033]4;167;rgb:fb/49/34\033\\"
  printf "\033]4;142;rgb:b8/bb/26\033\\"
  printf "\033]4;214;rgb:fa/bd/2f\033\\"
  printf "\033]4;109;rgb:83/a5/98\033\\"
  printf "\033]4;175;rgb:d3/86/9b\033\\"
  printf "\033]4;108;rgb:8e/c0/7c\033\\"
  printf "\033]4;208;rgb:fe/80/19\033\\"

  printf "\033]4;88;rgb:9d/00/06\033\\"
  printf "\033]4;100;rgb:79/74/0e\033\\"
  printf "\033]4;136;rgb:b5/76/14\033\\"
  printf "\033]4;24;rgb:07/66/78\033\\"
  printf "\033]4;96;rgb:8f/3f/71\033\\"
  printf "\033]4;66;rgb:42/7b/58\033\\"
  printf "\033]4;130;rgb:af/3a/03\033\\"
fi

==> vim-gruvbox_3.6.1.orig.tar.gz: gruvbox-3.6.1/gruvbox_256palette.sh <==
#!/bin/sh

if [ "${TERM%%-*}" = "screen" ] || [ "${TERM%%-*}" = "tmux" ]; then
  if [ -n "$TMUX" ]; then
    printf "\033Ptmux;\033\033]4;236;rgb:32/30/2f\007\033\\"
    printf "\033Ptmux;\033\033]4;234;rgb:1d/20/21\007\033\\"

    printf "\033Ptmux;\033\033]4;235;rgb:28/28/28\007\033\\"
    printf "\033Ptmux;\033\033]4;237;rgb:3c/38/36\007\033\\"
    printf "\033Ptmux;\033\033]4;239;rgb:50/49/45\007\033\\"
    printf "\033Ptmux;\033\033]4;241;rgb:66/5c/54\007\033\\"
    printf "\033Ptmux;\033\033]4;243;rgb:7c/6f/64\007\033\\"

    printf "\033Ptmux;\033\033]4;244;rgb:92/83/74\007\033\\"
    printf "\033Ptmux;\033\033]4;245;rgb:92/83/74\007\033\\"

    printf "\033Ptmux;\033\033]4;228;rgb:f2/e5/bc\007\033\\"
    printf "\033Ptmux;\033\033]4;230;rgb:f9/f5/d7\007\033\\"

    printf "\033Ptmux;\033\033]4;229;rgb:fb/f1/c7\007\033\\"
    printf "\033Ptmux;\033\033]4;223;rgb:eb/db/b2\007\033\\"
    printf "\033Ptmux;\033\033]4;250;rgb:d5/c4/a1\007\033\\"
    printf "\033Ptmux;\033\033]4;248;rgb:bd/ae/93\007\033\\"
    printf "\033Ptmux;\033\033]4;246;rgb:a8/99/84\007\033\\"

    printf "\033Ptmux;\033\033]4;167;rgb:fb/49/34\007\033\\"
    printf "\033Ptmux;\033\033]4;142;rgb:b8/bb/26\007\033\\"
    printf "\033Ptmux;\033\033]4;214;rgb:fa/bd/2f\007\033\\"
    printf "\033Ptmux;\033\033]4;109;rgb:83/a5/98\007\033\\"
    printf "\033Ptmux;\033\033]4;175;rgb:d3/86/9b\007\033\\"
    printf "\033Ptmux;\033\033]4;108;rgb:8e/c0/7c\007\033\\"
    printf "\033Ptmux;\033\033]4;208;rgb:fe/80/19\007\033\\"

    printf "\033Ptmux;\033\033]4;88;rgb:9d/00/06\007\033\\"
    printf "\033Ptmux;\033\033]4;100;rgb:79/74/0e\007\033\\"
    printf "\033Ptmux;\033\033]4;136;rgb:b5/76/14\007\033\\"
    printf "\033Ptmux;\033\033]4;24;rgb:07/66/78\007\033\\"
    printf "\033Ptmux;\033\033]4;96;rgb:8f/3f/71\007\033\\"
    printf "\033Ptmux;\033\033]4;65;rgb:42/7b/58\007\033\\"
    printf "\033Ptmux;\033\033]4;130;rgb:af/3a/03\007\033\\"
  else
    printf "\033P\033]4;236;rgb:32/30/2f\007\033\\"
    printf "\033P\033]4;234;rgb:1d/20/21\007\033\\"

    printf "\033P\033]4;235;rgb:28/28/28\007\033\\"
    printf "\033P\033]4;237;rgb:3c/38/36\007\033\\"
    printf "\033P\033]4;239;rgb:50/49/45\007\033\\"
    printf "\033P\033]4;241;rgb:66/5c/54\007\033\\"
    printf "\033P\033]4;243;rgb:7c/6f/64\007\033\\"

    printf "\033P\033]4;244;rgb:92/83/74\007\033\\"
    printf "\033P\033]4;245;rgb:92/83/74\007\033\\"

    printf "\033P\033]4;228;rgb:f2/e5/bc\007\033\\"
    printf "\033P\033]4;230;rgb:f9/f5/d7\007\033\\"

    printf "\033P\033]4;229;rgb:fb/f1/c7\007\033\\"
    printf "\033P\033]4;223;rgb:eb/db/b2\007\033\\"
    printf "\033P\033]4;250;rgb:d5/c4/a1\007\033\\"
    printf "\033P\033]4;248;rgb:bd/ae/93\007\033\\"
    printf "\033P\033]4;246;rgb:a8/99/84\007\033\\"

    printf "\033P\033]4;167;rgb:fb/49/34\007\033\\"
    printf "\033P\033]4;142;rgb:b8/bb/26\007\033\\"
    printf "\033P\033]4;214;rgb:fa/bd/2f\007\033\\"
    printf "\033P\033]4;109;rgb:83/a5/98\007\033\\"
    printf "\033P\033]4;175;rgb:d3/86/9b\007\033\\"
    printf "\033P\033]4;108;rgb:8e/c0/7c\007\033\\"
    printf "\033P\033]4;208;rgb:fe/80/19\007\033\\"

    printf "\033P\033]4;88;rgb:9d/00/06\007\033\\"
    printf "\033P\033]4;100;rgb:79/74/0e\007\033\\"
    printf "\033P\033]4;136;rgb:b5/76/14\007\033\\"
    printf "\033P\033]4;24;rgb:07/66/78\007\033\\"
    printf "\033P\033]4;96;rgb:8f/3f/71\007\033\\"
    printf "\033P\033]4;65;rgb:42/7b/58\007\033\\"
    printf "\033P\033]4;130;rgb:af/3a/03\007\033\\"
  fi

elif [ "$TERM" = "fbterm" ]; then
  printf "\033[3;236;50;48;47}"
  printf "\033[3;234;29;32;33}"

  printf "\033[3;235;40;40;40}"
  printf "\033[3;237;60;56;54}"
  printf "\033[3;239;80;73;69}"
  printf "\033[3;241;102;92;84}"
  printf "\033[3;243;124;111;100}"

  printf "\033[3;244;146;131;116}"
  printf "\033[3;245;146;131;116}"

  printf "\033[3;228;242;229;188}"
  printf "\033[3;230;249;245;215}"

  printf "\033[3;229;253;244;193}"
  printf "\033[3;223;235;219;178}"
  printf "\033[3;250;213;196;161}"
  printf "\033[3;248;189;174;147}"
  printf "\033[3;246;168;153;132}"

  printf "\033[3;167;251;73;52}"
  printf "\033[3;142;184;187;38}"
  printf "\033[3;214;250;189;47}"
  printf "\033[3;109;131;165;152}"
  printf "\033[3;175;211;134;155}"
  printf "\033[3;108;142;192;124}"
  printf "\033[3;208;254;128;25}"

  printf "\033[3;88;157;0;6}"
  printf "\033[3;100;121;116;14}"
  printf "\033[3;136;181;118;20}"
  printf "\033[3;24;7;102;120}"
  printf "\033[3;96;143;63;113}"
  printf "\033[3;65;66;123;88}"
  printf "\033[3;130;175;58;3}"

elif [ "$TERM" != "linux" ] && [ "$TERM" != "vt100" ] && [ "$TERM" != "vt220" ]; then

  printf "\033]4;236;rgb:32/30/2f\033\\"
  printf "\033]4;234;rgb:1d/20/21\033\\"

  printf "\033]4;235;rgb:28/28/28\033\\"
  printf "\033]4;237;rgb:3c/38/36\033\\"
  printf "\033]4;239;rgb:50/49/45\033\\"
  printf "\033]4;241;rgb:66/5c/54\033\\"
  printf "\033]4;243;rgb:7c/6f/64\033\\"

  printf "\033]4;244;rgb:92/83/74\033\\"
  printf "\033]4;245;rgb:92/83/74\033\\"

  printf "\033]4;228;rgb:f2/e5/bc\033\\"
  printf "\033]4;230;rgb:f9/f5/d7\033\\"

  printf "\033]4;229;rgb:fb/f1/c7\033\\"
  printf "\033]4;223;rgb:eb/db/b2\033\\"
  printf "\033]4;250;rgb:d5/c4/a1\033\\"
  printf "\033]4;248;rgb:bd/ae/93\033\\"
  printf "\033]4;246;rgb:a8/99/84\033\\"

  printf "\033]4;167;rgb:fb/49/34\033\\"
  printf "\033]4;142;rgb:b8/bb/26\033\\"
  printf "\033]4;214;rgb:fa/bd/2f\033\\"
  printf "\033]4;109;rgb:83/a5/98\033\\"
  printf "\033]4;175;rgb:d3/86/9b\033\\"
  printf "\033]4;108;rgb:8e/c0/7c\033\\"
  printf "\033]4;208;rgb:fe/80/19\033\\"

  printf "\033]4;88;rgb:9d/00/06\033\\"
  printf "\033]4;100;rgb:79/74/0e\033\\"
  printf "\033]4;136;rgb:b5/76/14\033\\"
  printf "\033]4;24;rgb:07/66/78\033\\"
  printf "\033]4;96;rgb:8f/3f/71\033\\"
  printf "\033]4;65;rgb:42/7b/58\033\\"
  printf "\033]4;130;rgb:af/3a/03\033\\"
fi
